@@ -7,9 +7,9 @@ module Initial_example = struct
       (List.quickcheck_generator Int.quickcheck_generator)
       ~sexp_of:[%sexp_of: int list]
       ~f:(fun list ->
-        [%test_eq: int]
-          (List.fold_left ~init:0 ~f:( + ) list)
-          (List.fold_right ~init:0 ~f:( + ) list))
+      [%test_eq: int]
+        (List.fold_left ~init:0 ~f:( + ) list)
+        (List.fold_right ~init:0 ~f:( + ) list))
   ;;
 end
 
@@ -312,7 +312,7 @@ module Example_3_asynchronous = struct
       match t.pops with
       | ivar :: rest ->
         t.pops <- rest;
-        Ivar.fill ivar x
+        Ivar.fill_exn ivar x
       | [] ->
         if Ivar.is_full t.push then t.push <- Ivar.create ();
         t.elts <- x :: t.elts
@@ -331,7 +331,7 @@ module Example_3_asynchronous = struct
         Ivar.read ivar
       | x :: rest ->
         t.elts <- rest;
-        if List.is_empty rest then Ivar.fill t.push ();
+        if List.is_empty rest then Ivar.fill_exn t.push ();
         Deferred.return x
     ;;
 
